Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

### - r -

- rank() : stan::math
- rayleigh_ccdf_log() : stan::math
- rayleigh_cdf() : stan::math
- rayleigh_cdf_log() : stan::math
- rayleigh_log() : stan::math
- rayleigh_rng() : stan::math
- read_corr_L() : stan::math
- read_corr_matrix() : stan::math
- read_cov_L() : stan::math
- read_cov_matrix() : stan::math
- recover_memory() : stan::math
- recover_memory_nested() : stan::math
- rep_array() : stan::math
- rep_matrix() : stan::math
- rep_row_vector() : stan::math
- rep_vector() : stan::math
- resize() : stan::math
- rising_factorial() : stan::math
- round() : stan::math
- row() : stan::math
- rows() : stan::math
- rows_dot_product() : stan::math
- rows_dot_self() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.